<div style="height: 100%; padding: 0px">
    <!--button style="position: absolute; top: 220px; right: 25px;" class="btn btn-shim btn-labeled btn-lg fa fa-plus btn-mint" data-bind="click: function(){complete(true)}">complete</button-->
    <!-- ko if: card() -->
        <!-- ko component: {
            name: cardComponentLookup[card().model.component_id()].componentname,
            params: {
                card: card(),
                tile: tile(),
                provisionalTileViewModel: provisionalTileViewModel,
                reviewer: reviewer,
                loading: loading,
                form: $data,
                pageVm: $root
            }
        } --><!-- /ko -->
    <!-- /ko -->
</div>
