{% load i18n %}

<div style="height:0px">
  <div class="row widget-container">
    <div class="form-group">
      <div class="col-xs-12">
        <label class="col-xs-12 control-label widget-input-label" for="geojsonNode"> {% trans "GeoJSON Node" %}</label>
        <select data-placeholder="{% trans "Choose a card." %}"
          data-bind="chosen: {width: '100%', disable_search_threshold: 15}, value: geojson_input_node, options: nodesGeoJSON, optionsText: 'name', optionsValue: 'nodeid', valueAllowUnset: true"
          id="geojsonNode"></select>
      </div>
    </div>

    <div class="form-group">
      <div class="col-xs-12">
        <label class="col-xs-12 control-label widget-input-label" for="bngNode"> {% trans "BNG Node" %}</label>
        <select data-placeholder="{% trans "Choose a card." %}"
          data-bind="chosen: {width: '100%', disable_search_threshold: 15}, value: bng_output_node, options: nodesBNG, optionsText: 'name', optionsValue: 'nodeid', valueAllowUnset: true"
          id="bngNode"></select>
      </div>
    </div>

  </div>
</div>