<!-- ko if: tile() && card() -->
<div class="padded-workflow-step">
    <div>
        <h2 style="font-size:32px;" data-bind="text:'Template successfully saved to Consultation'"></h2>
        <div>
            <a data-bind="attr: {href: dataURL}" download><button class="btn btn-success btn-shim btn-labeled btn-lg fa fa-download">Download Letter</button></a>
            <button class="btn btn-shim btn-labeled btn-lg fa fa-caret-right btn-mint" data-bind="click: function(){complete(true)}">Continue</button>
        </div>
    </div>
</div>
<!-- /ko -->
