{% load i18n %}
<div style="height: 100%; padding: 10px 24px;">
    <div style="padding: 5px 5px 5px 65px">
        <div class="widget-input-label">Select Related Consultation</div>
        <div data-bind="component: {
            name: 'resource-instance-select-widget',
            params: {
                graphids: [
                    '8d41e49e-a250-11e9-9eab-00224800b26d',
                ],
                renderContext: 'workflow',
                value: resourceValue,
                disabled: locked,
            }
        }"></div>
    </div>
    <!-- ko if: tile() && card() && resourceValue() -->
    <!--div data-bind="class: workflowStepClass"-->
        <div data-bind="component: {
            name: cardComponentLookup[card().model.component_id()].componentname,
            params: {
                card: card(),
                tile: tile(),
                provisionalTileViewModel: provisionalTileViewModel,
                reviewer: reviewer,
                loading: loading,
                form: $data,
                pageVm: $root
            }
        }">
        </div>
    <!--/div-->
    <!-- /ko -->
</div>
