.bng-search-container .filter-title {
    margin-top: 3px;
    margin-bottom: 15px;
}

.bng-search-map {
    padding: 0px;
    height: 400px;
}

.bng-search-container > input {
    width: 100%;
}

.bng-search-input-container{
    margin-top: 5px;
}

.bng-search-info {
    padding: 5px;
    padding-left: 20px;
    font-size: 1.1rem;
}

.bng-search-info-text {
    padding-left: 5px;
}

.bng-search-input {
    padding: 5px;
}

.bng-search-error {
    color: red;
    border: red;
}