$font-family-main: Helvetica Neue, Helvetica, Arial, sans-serif;
$focus-outline: #EC6625;
$list-items: #333;
$standard-links: #2579A4;
$headings: #555;
$background-header: #041B33;
$backgrounds: #F8F8F8;
$box-shadow: #00000029;
$header-border-mobile: #D4D4D4;
$page-content-seperators: #707070;
$jumbotron-bg: #F9F7F6;
$footer-text: #FFF;
$footer-text-hint: #000;
$footer-top-bg: #062647;
$footer-bottom-bg: #041B33;
$skiptocontent-link: #000;
$skiptocontent-bg: #fae619;