update graphs set templateid = 'eeb7054c-df37-45d1-8f09-39abb582077e' where graphid = 'b9e0701e-5463-11e9-b5f5-000d3ab1e588'; -- Activity
update graphs set templateid = '9ed340ba-88c6-4982-9487-c3aae4b14d16' where graphid = '42ce82f6-83bf-11ea-b1e8-f875a44e0e11'; -- Application Area
update graphs set templateid = 'b32fc2f2-5570-46c2-8d1e-09ca54c750ab' where graphid = '343cc20c-2c5a-11e8-90fa-0242ac120005'; -- Artefact
update graphs set templateid = '44fdae23-7883-4d5c-88fa-7498b6fc898d' where graphid = '24d7b54f-5464-11e9-a86b-000d3ab1e588'; -- Bibliographic Source
update graphs set templateid = '465443ea-0e01-4895-a9cf-5144b02213da' where graphid = '8d41e49e-a250-11e9-9eab-00224800b26d'; -- Consultation
update graphs set templateid = '2bf88426-a053-4134-b006-d4dc2e120a6e' where graphid = 'a535a235-8481-11ea-a6b9-f875a44e0e11'; -- Digital Object
update graphs set templateid = 'c6f163ca-3ca5-4c50-b398-bee406fe059d' where graphid = '979aaf0b-7042-11ea-9674-287fcf6a5e72'; -- Area
update graphs set templateid = '523a5a7f-006b-4caf-a801-a1621967a88b' where graphid = '076f9381-7b00-11e9-8d6b-80000b44d1d9'; -- Monument
update graphs set templateid = '6858ba4d-70a2-4e78-baf1-c827dd66956b' where graphid = '0add0e11-99aa-11ea-9ab8-f875a44e0e11'; -- Heritage Story
update graphs set templateid = '655f86f0-643a-4df4-be8b-9e9030d2ff94' where graphid = 'b8032b00-594d-11e9-9cf0-18cf5eb368c4'; -- Historic Aircraft
update graphs set templateid = '5c757462-97d9-43fc-bd39-54367f6f3c2e' where graphid = '934cd7f0-480a-11ea-9240-c4d9877d154e'; -- Historic Landscape Characterization
update graphs set templateid = '03871d64-7076-46e8-b0ed-4b8813b0afd4' where graphid = '49bac32e-5464-11e9-a6e2-000d3ab1e588'; -- Maritime Vessel
update graphs set templateid = '407019fd-69e4-4aa4-a054-1466acaf8687' where graphid = 'd4a88461-5463-11e9-90d9-000d3ab1e588'; -- Organization
update graphs set templateid = '4c2ed0b0-c278-49e2-9ddf-ba44aa77a6f3' where graphid = 'f9045867-8861-11ea-b06f-f875a44e0e11'; -- Period
update graphs set templateid = '9e9f8e55-3ea9-4bd3-8b11-c1a519fbcfcc' where graphid = '22477f01-1a44-11e9-b0a9-000d3ab1e588'; -- Person
update graphs set templateid = '6b183add-a159-4d2b-a6b0-3f426d8c08a1' where graphid = '78b32d8c-b6f2-11ea-af42-f875a44e0e11'; -- Place