{% extends "views/report-templates/default.htm" %}
{% load i18n %}
{% block report %}

{% block body %}

<h2 class="aher-report-section-title"><i tabindex="0" data-bind="onEnterkeyClick, onSpaceClick, click: function() {toggleVisibility(visible.referencedBy)}, onReportSectionToggleAria: visible.referencedBy, sectionName: '{% trans "Resource Referenced By" %}'" class="fa toggle"></i> {% trans "Resource Referenced By" %}</h2>
<!-- Collapsible content -->
<div data-bind="visible: visible.referencedBy" class="aher-report-collapsible-container pad-lft">

    <!-- ko if: relations().length == 0 -->
    <div class="aher-nodata-note">{% trans "No resource referenced by for this resource" %}</div>
    <!-- /ko -->

    <!-- ko if: relations().length > 0 -->
    <div class="aher-report-subsection">
        <div class="firstchild-container">
            <div class="aher-table">
                <table id="referenced-by-table" class="table table-striped" cellspacing="0" width="100%">
                    <thead>
                        <tr>
                            <th>{% trans "Related Resource" %}</th>
                            <th>{% trans "Resource Type" %}</th>
                        </tr>
                    </thead>
                    <tbody data-bind="dataTablesForEach: { data: relations, dataTableOptions: referencedByTwoColumnTableConfig}">
                        <tr>
                            <td>
                                <!-- ko if: related_resource_link -->
                                <a data-bind="text: related_resource_name, attr: {href: related_resource_link}" class="aher-table-link"></a>
                                <!-- /ko -->
                                <!-- ko ifnot: related_resource_link -->
                                <span data-bind="text: related_resource_name"></span>
                                <!-- /ko -->
                            </td>
                            <td data-bind="text: related_resource_type"></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    <!-- /ko -->
</div>





{% endblock body %}
{% endblock report %}
{% block summary %}

<div class="model-summary-report">
Do not use - yet.
</div>

{% endblock summary %}