{% load i18n %}
<!-- ko if: $data.search -->
<div class="col-md-4 col-lg-3">
    <select class="resources" data-bind="value: op, chosen: {width: '100%', disable_search_threshold: 15}">
        <option value="~">{% trans "Like" %}</option>
        <option value="!~">{% trans "Not like" %}</option>
        <option value="">{% trans "Equals" %}</option>
        <option value="!">{% trans "Is Not" %}</option>
        <option value="null">{% trans "Has no value" %}</option>
        <option value="not_null">{% trans "Has any value" %}</option>
    </select>
</div>

<div class="col-md-8 col-lg-9" data-bind="visible: op() !== 'null' && op() !== 'not_null'">
    <input type="text" placeholder='{% trans "National Grid Reference" %}' class="form-control input-lg" style="height: 36px;" data-bind="value: searchValue, valueUpdate: 'keyup'">
</div>
<!-- /ko -->