<!DOCTYPE html>
<html>

    <head>
        {% include 'custom_email_css.htm' %}
    </head>

    <body>
        {% include 'custom_email_header.htm' %}

        {% if username != "" %}
            <p>
                {{salutation}} {{username}},
            </p>
        {% endif %}
        <p>
            {{greeting}}
        </p>
        {% if link != "" %}
            <p>
                <a href="{{link}}">
                    {{link_text}}
                </a>
            </p>
        {% endif %}

        {% include 'custom_email_footer.htm' %}

    </body>
    
</html>