.menu-title {
    font-size: 1.7rem;
}

.search-result {
    padding: 10px;
    border-bottom: solid 1px lightgray;
    font-weight: 600;
}

.search-result > a {
    color: #000071;
}

.search-result > a:hover {
    color: #2e29da;
}

.cons-search-results-container .search-result.selected {
    background: #fff;
    border-bottom-color: #25476A;
}

#map-popup .map-popup-content {
    margin: -1px 0px 0px 0px;
    border-width: 0px;
}

.map-popup-content {
    border: 1px solid #ddd;
    background: #fff;
    margin: 3px;
}

.map-popup-content .map {
    overflow: hidden;
    height: 200px;
    padding: 0px;
    text-align: center;
    background-color: #f8fbff;
    position: relative;
    margin-top: 1px;
}

.map-popup-content section {
    padding: 15px 15px 20px 15px;
    color: #25476A;
    font-weight: 400;
    border-bottom: solid 1px #ddd;
}

.map-popup-content section:last-child {
    border-bottom: none;
    padding-bottom: 60px;
}

.cons-summary {
    height: 100%;
    overflow-y: scroll;
}

.map-popup-content section .title {
    font-size: 1.5rem;
    font-weight: 400;
}

.cons-attribute {
    margin-bottom: 7px;
}

.map-popup-content .title {
    font-size: 1.4rem;
    font-weight: bold;
}

.map-popup-content section .popup-label {
    font-weight: 400;
}

.map-popup-content section .popup-value {
    color: #777;
}

.map-popup-content .popup-label {
    font-weight: bold;
}

#map-popup {
    position: relative;
    top: 0px;
    bottom: 0px;
    z-index: 10;
    left: 0px;
    background: white;
    display: flex;
    flex-direction: column;
    border: none;
    border-right: 1px solid #BBD1EA;
    display: none;
}

#map-popup .hover-feature-body {
    flex: 1 1 auto;
    overflow-y: scroll;
    height: calc(100% - 96px);
}
