<!-- ko if: tile() && card() -->
<div>
    <div data-bind="component: {
        name: cardComponentLookup[card().model.component_id()].componentname,
        params: {
            card: card(),
            tile: tile(),
            provisionalTileViewModel: provisionalTileViewModel,
            reviewer: reviewer,
            loading: loading,
            form: $data,
            pageVm: $root
        }
    }"></div>
</div>
<!-- /ko -->
