@import "project-functions";
@import "project-variables";

/***********************************************************************************/
/* Landing page                                                                    */
/***********************************************************************************/

html, body {
    font-size: 0.6rem;
}

body {
    background-color: $backgrounds;
}

.landing-page {
	/* General - Start*/
    font-family: $font-family-main;
	font-size: 1.125rem;
	font-weight: 300;
	overflow-x: hidden;
	min-width: 100vw;

    a {
		&:focus {
			outline: 2px solid $focus-outline !important;
		}
	}
    #skip-link-holder {
        a, a:link, a:visited {
            color: $skiptocontent-link;
            background-color: $skiptocontent-bg;
            font-weight: bold;
            text-decoration: none;
            padding: 10px;
            text-align: center;
            outline: none !important;
            max-height: 38px;
            display: block;
            width: 100%;
            position: fixed;
            top: -38px;
            left: 0;
            z-index: 10001;
        }
        a:focus, a:active {
            text-decoration: underline !important;
            left: 0;
            top: 0;
            z-index: 10000000;
        }
    }
    #skip-target-holder {
        position: absolute;
        top: -38px;
        left: 0;
    }
	input {
		&:focus {
			outline: 2px solid $focus-outline !important;
		}
	}
	button {    
		&:focus {
			outline: 2px solid $focus-outline !important;
		}
	}
	.form-control {
		&:focus {
			outline: 2px solid $focus-outline !important;
		}
	}
    p {
        font-size: 1.8rem;
    }
    a:not(.caption a):not(.footer-top-contact-details a) {
        font-size: 1.8rem;
    }
    li {
        font-size: 1.8rem;
        color: $list-items;
    }
    a:not(.btn-primary):not(footer a) {
        color: $standard-links;
    }
    .btn-primary {
        height: 51px;
        padding: 12px 16px;
        font-weight: 300;
        line-height: 1.5;
    }
    .navbar-nav {
		>li {
			>a {
				font-weight: 400;
				line-height: 49px;
				padding: 15px;
			}
		}
	}
    .container {
        width: 100%;
        max-width: 1440px;
        @include break-at(wide-max) {
            max-width: 1000px;
        }
        @include break-at(tablet-max) {
            max-width: 800px;
        }
        @include break-at(mobile-lg-max) {
            max-width: 100vw;
        }
        padding: 0 64px;
        @include break-at(wide-max) {
            padding: 0 60px;
        }
        @include break-at(tablet-max) {
            padding: 0 50px;
        }
        @include break-at(mobile-lg-max) {
            padding: 0;
        }
    }
    .no-transition {
        -webkit-transition: height 0;
        -moz-transition: height 0;
        -ms-transition: height 0;
        -o-transition: height 0;
        transition: height 0;
    }
    ul.nav {
		li {
			a {
				font-size: 1.6rem !important;
			}
		}
	}
    h1 {
        font-size: 4.7rem;
        @include break-at(tablet-max) {
            font-size: 3.4rem;
        }
        @include break-at(mobile-xsmall-max) {
            font-size: 2.5rem;
        }
        color: $headings;
    }
    h2 {
        font-size: 3.4rem;
        @include break-at(mobile-lg-max) {
            font-size: 2.6rem;
        }
        @include break-at(mobile-xsmall-max) {
            font-size: 2.4rem;
        }
        margin-bottom: 20px;
        color: $headings;
    }
    
    h3 {
        font-size: 2.5rem;
        margin-bottom: 20px;
        color: $headings;
    }
    li {
        font-size: 1.8rem;
    }
    .caption {
        padding: 20px 17px 20px 20px;
        font-size: 1.8rem;
        @include break-at(tablet-max) {
            font-size: 1.8rem;
        }
    }
    video {
        width: 100%;
        min-width: 300px;
        border-radius: 10px;
    }
    .img-rounded {
        border-radius: 10px;
        @include break-at(mobile-lg-max) {
            border-radius: 0;
        }
    }
    /* General - End */
    /* Header  - Start */
    header {
        position: relative;
        width: 100%;
        height: 80px;
        @include break-at(mobile-lg-max) {
            height: 60px;
        }
        box-shadow: 0px 3px 6px $box-shadow;
        @include break-at(mobile-lg-max) {
            box-shadow: none;
        }
        margin-bottom: 30px;
        @include break-at(mobile-lg-max) {
            margin-bottom: 0;
        }
        top: 0px;
        z-index: 500;
        background-color: $background-header;
        border: none;
        @include break-at(mobile-lg-max) {
            border-bottom: 1px solid $header-border-mobile;
        }
        border-radius: 0px;
        .navbar {
            .container-fluid {
                padding-left: 60px;
                @include break-at(tablet-max) {
                    padding-left: 50px;
                }
                @include break-at(mobile-lg-max) {
                    padding-left: 15px;
                }
                padding-right: 60px;
                @include break-at(tablet-max) {
                    padding-right: 50px;
                }
                @include break-at(mobile-lg-max) {
                    padding-right: 15px;
                }
                max-width: 1440px;
                @include break-at(wide-max) {
                    max-width: 1000px;
                }
                @include break-at(tablet-max) {
                    max-width: 800px;
                }
                .navbar-header {
                    height: 80px;
                    @include break-at(mobile-lg-max) {
                        height: 60px;
                    }
                    .navbar-toggle {
                        right: 0;
                        margin: 0;
                        @include break-at(mobile-lg-max) {
                            right: 30px;
                        }
                        .icon-bar {
                            background: #FFF;
                        }
                    }
                    .icon-bar {
                        background: $standard-links;
                    }
                    .nav-brand-container {
                        padding: 0;
                        .navbar-brand {
                            height: 80px;
                            padding-top: 17px;
                            @include break-at(mobile-lg-max) {
                                padding: 13px 15px;
                                height: 60px;
                            }
                            .navbar-brand-image {
                                width: 200px;
                                @include break-at(mobile-lg-max) {
                                    width: 150px;
                                }
                            }
                        }
                    }
                }
                .navbar-collapse {
                    padding: 0;
                    &.collapsing {
                        display: none;
                    }
                    a {
                        color: #FFF;
                        &:hover {
                            background: #000;
                            color: #13ce67;
                        }
                        &:active {
                            background: #000;
                            color: #13ce67;
                        }
                        &:focus {
                            background: #000;
                            color: #13ce67;
                        }
                    }
                    &.collapse {
                        .container {
                            @include break-at(medium-desktop-min) {
                                padding: 0;
                            }
                            .navbar-right {
                                @include break-at(medium-desktop-max) {
                                    float: none!important;
                                }
                            }
                        }
                        &.in {
                            z-index: 9999;
                            position: absolute;
                            top: 58px;
                            @include break-at(mobile-lg-max) {
                                top: 57px;
                            }
                            right: -3px;
                            @include break-at(mobile-lg-max) {
                                right: 14px;
                            }
                            @include break-at(mobile-xsmall-max) {
                                right: 14px;
                            }
                            width: 40vw;
                            @include break-at(mobile-xsmall-max) {
                                width: 60vw;
                            }
                            background: $background-header;
                            overflow-x: hidden;
                            padding: 20px!important;
                            li {
                                a {
                                    line-height: 20px;
                                    @include break-at(mobile-lg-max) {
                                        font-size: 1.3rem!important;
                                    }
                                }
                            }
                            .navbar-nav {
                                margin: 0;
                            }
                        }
                    }
                }
            }
        }
    }
    /* Header  - End */
    /* Main - Start*/
    main {
        .featurette-image-block {
            box-shadow: 0px 3px 6px $box-shadow;
            max-width: 423px;
            margin: 10px;
            @include break-at(wide-max) {
                max-width: 440px;
            }
            @include break-at(tablet-max) {
                max-width: 337px;
            }
            @include break-at(mobile-lg-max) {
                max-width: 440px;
            }
            padding: 0;
            display: inline-block;
        }
        .featurette1 {
            margin-left: inherit;
            margin-right: inherit;
            position: relative;
            .featurette1-left-container {
                width: 444px;
                @include break-at(wide-max) {
                    width: calc(100% - 148px);
                }
                @include break-at(tablet-max) {
                    width: calc(100% - 60px);
                }
                @include break-at(mobile-lg-max) {
                    width: 100vw;
                }
                position: absolute;
                left: 0;
                @include break-at(wide-max) {
                    left: 74px;
                }
                @include break-at(tablet-max) {
                    left: 30px;
                }
                @include break-at(mobile-xsmall-max) {
                    left: 15px;
                }
                top: 50%;
                transform: translateY(-50%);
                @include break-at(wide-max) {
                    top: 570px;
                }
                @include break-at(tablet-max) {
                    top: 425px;
                }
                @include break-at(mobile-lg-max) {
                    top: 76vw;
                }
                @include break-at(mobile-mid-max) {
                    top: 88vw;
                }
                border-radius: 10px;
                @include break-at(mobile-lg-max) {
                    border-radius: 0;
                }
                background-color: $backgrounds;
                padding: 0 20px 0 0;
                @include break-at(wide-max) {
                    padding: 0px 102px;
                }
                @include break-at(tablet-max) {
                    padding: 0px 20px;
                }
                @include break-at(mobile-lg-max) {
                    padding: 0 47px 0 0;
                }
                @include break-at(mobile-xsmall-max) {
                    padding: 0 30px 0 0;
                }
                h1 {
                    margin-top: 30px;
                    @include break-at(tablet-max) {
                        margin-top: 20px;
                    }
                    @include break-at(mobile-lg-max) {
                        margin-top: 0;
                    }
                    br {
                        display: block;
                        @include break-at(tablet-max) {
                            display: none;
                        }
                    }
                }
                p {
                    font-size: 2.2rem;
                    @include break-at(tablet-max) {
                        font-size: 2rem;
                    }
                }
            }
            .featurette1-right-container {
                padding: 0;
                width: 1090px;
                @include break-at(wide-max) {
                    width: 100%;
                }
                @include break-at(tablet-max) {
                    width: 100%;
                }
            }
        }
        .featurette2 {
            margin: 50px auto 0 auto;
            @include break-at(wide-max) {
                margin-top: 243px;
            }
            @include break-at(tablet-max) {
                margin-top: 179px;
            }
            @include break-at(mobile-lg-max) {
                margin: 253px 15px 0 30px;
            }
            @include break-at(mobile-xsmall-max) {
                margin: 230px 15px 0 15px;
            }
            border-top: 1px solid $page-content-seperators;
            border-bottom: 1px solid $page-content-seperators;
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 500px;
            }
            @include break-at(tablet-max) {
                max-width: 580px;
            }
            @include break-at(mobile-lg-max) {
                max-width: 100%;
            }
            ol {
                -moz-column-count: 2;
                -moz-column-gap: 20px;
                -webkit-column-count: 2;
                -webkit-column-gap: 20px;
                column-count: 2;
                @include break-at(mobile-lg-max) {
                    column-count: 1;
                    padding-left: 30px;
                }
                column-gap: 20px;
                li {
                    @include break-at(mobile-lg-max) {
                        margin-bottom: 10px;
                    }
                }
            }
        }
        .featurette3 {
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 500px;
            }
            @include break-at(tablet-max) {
                max-width: 100%;
            }
            margin: 50px auto 0 auto;
            @include break-at(mobile-lg-max) {
                margin: 40px 15px 0 30px;
            }
            @include break-at(mobile-xsmall-max) {
                margin: 40px 15px 0 15px;
            }
            .subtitle {
                font-size: 2.2rem;
            }
            .featurette3-row{
                margin-left: -128px;
                @include break-at(wide-max) {
                    margin-left: -217px;
                }
                @include break-at(tablet-max) {
                    margin-left: -40px;
                }
                @include break-at(mobile-lg-max) {
                    margin-left: 0;
                }
                margin-right: -128px;
                @include break-at(wide-max) {
                    margin-right: -217px;
                }
                @include break-at(tablet-max) {
                    margin-right: -60px;
                }
                @include break-at(mobile-lg-max) {
                    margin-right: 0;
                }
                margin-top: 30px;
                .featurette3-first-block {
                    margin-right: 20px;
                    @include break-at(mobile-lg-max) {
                        margin-right: 10px;
                    }
                }
                img {
                    @include break-at(wide-max) {
                        width: 438px;
                    }
                }
            }
        }
        .featurette4 {
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 500px;
            }
            @include break-at(tablet-max) {
                max-width: 100%;
            }
            margin: 50px auto 0 auto;
            @include break-at(mobile-lg-max) {
                margin: 40px 15px 0 30px;
            }
            @include break-at(mobile-xsmall-max) {
                margin: 40px 15px 0 15px;
            }
            .featurette4-row {
                margin: 30px -113px 20px -113px;
                @include break-at(tablet-max) {
                    margin: 30px -23px 20px -30px;
                }
                @include break-at(mobile-lg-max) {
                    margin: 30px 0 20px 0;
                }
            }
        }
        .featurette5 {
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 500px;
            }
            @include break-at(tablet-max) {
                max-width: 100%;
            }
            margin: 50px auto 0 auto;
            @include break-at(mobile-lg-max) {
                margin: 40px 15px 0 30px;
            }
        }
        .featurette6 {
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 500px;
            }
            @include break-at(tablet-max) {
                max-width: 100%;
            }
            margin: 50px auto 0 auto;
            @include break-at(mobile-lg-max) {
                margin: 40px 15px 0 30px;
            }
            @include break-at(mobile-xsmall-max) {
                margin: 40px 15px 0 15px;
            }
            .featurette6-row {
                margin-left: -346px;
                @include break-at(wide-max) {
                    margin-left: -203px;
                }
                @include break-at(tablet-max) {
                    margin-left: -24px;
                }
                @include break-at(mobile-lg-max) {
                    margin-left: 0;
                }
                margin-right: -346px;
                @include break-at(wide-max) {
                    margin-right: -203px;
                }
                @include break-at(tablet-max) {
                    margin-right: -50px;
                }
                @include break-at(mobile-lg-max) {
                    margin-right: 0;
                }
                margin-top: 30px;
            }
        }
        .featurette7 {
            max-width: 646px;
            @include break-at(wide-max) {
                max-width: 580px;
            }
            @include break-at(tablet-max) {
                max-width: 100%;
            }
            margin: 50px auto 0 auto;
            @include break-at(mobile-lg-max) {
                margin: 40px 15px 0 30px;
            }
            @include break-at(mobile-xsmall-max) {
                margin: 40px 15px 0 15px;
            }
            .jumbotron {
                padding: 20px;
                background: $jumbotron-bg;
                @include break-at(mobile-lg-max) {
                    border-radius: 0;
                }
                h3 {
                    margin-top: 0;
                }
                p {
                    margin-bottom: 0;
                }
                .btn {
                    margin-left: 35px;
                    @include break-at(mobile-lg-max) {
                        margin-left: 0;
                    }
                }
                .website-details {
                    margin-bottom: 20px;
                    margin-left: -15px!important;
                    .contact-icon {
                        display: inline-block;
                        vertical-align: top;
                        margin-right: 10px;
                    }
                    .contact-details {
                        display: inline-block;
                        padding-left: 5px;
                    }
                }
                .address-phone {
                    margin-left: -15px!important;
                    .contact-icon {
                        display: inline-block;
                        vertical-align: top;
                        margin-right: 10px;
                    }
                    .contact-details {
                        display: inline-block;
                        margin-bottom: 20px;
                        padding-left: 5px;
                    }
                }
            }
        }
    }
    /* Main - End*/
    /* Footer - Start */
    footer {
        margin-top: 80px;
        @include break-at(mobile-lg-max) {
            margin-top: 40px;
        }
        p {
            color: $footer-text;
            font-size: 1.8rem;
            .bg-info {
                color: $footer-text-hint;
            }
        }
        a {
            color: $footer-text;
            font-size: 1.8rem;
            margin-right: 25px;
        }
        .footer-top {
            min-height: 266px;
            background: $footer-top-bg;
            padding-top: 46px;
            .container {
                .footer-top-first-row {
                    margin-bottom: 30px;
                    @include break-at(mobile-lg-max) {
                        padding-left: 15px;
                    }
                    .footer-your-logo {
                        max-height: 40px;
                        @include break-at(tablet-max) {
                            max-height: 30px;
                        }
                        @include break-at(mobile-lg-max) {
                            max-height: 37px;
                        }
                        width: auto;
                    }
                    .footer-getty-logo {
                        max-height: 40px;
                        @include break-at(tablet-max) {
                            max-height: 30px;
                        }
                        @include break-at(mobile-lg-max) {
                            max-height: 37px;
                            margin: 30px 0; 
                        }
                        width: auto;
                    }
                    .footer-arches-logo {
                        max-height: 40px;
                        @include break-at(tablet-max) {
                            max-height: 30px;
                        }
                        @include break-at(mobile-lg-max) {
                            max-height: 37px;
                        }
                        width: auto;
                    }
                }
                .glher-text-container {
                    @include break-at(tablet-max) {
                        width: 66.66666667%;
                    }
                    @include break-at(mobile-lg-max) {
                        float: none;
                        width: 100vw;
                    }
                    .glaas-title {
                        font-size: 2.8rem;
                        @include break-at(mobile-lg-max) {
                            font-size: 2.6rem;
                            margin-bottom: 20px;
                            padding-left: 15px;
                        }
                        br {
                            display: block;
                            @include break-at(tablet-max) {
                                display: none;
                            }
                        }
                    }
                }
                .footer-top-contact-details {
                    @include break-at(tablet-max) {
                        width: 33.33333333%;
                    }
                    @include break-at(mobile-lg-max) {
                        margin-bottom: 30px;
                        float: none;
                        width: 100vw;
                    }
                    p {
                        font-size: 1.6rem;
                        @include break-at(mobile-lg-max) {
                            padding-left: 15px;
                        }
                    }
                    a {
                        font-size: 1.6rem;
                        text-decoration: underline;
                    }
                }
            }
        }
        .footer-bottom {
            min-height: 60px;
            background: $footer-bottom-bg;
            .footer-container {
                min-height: 60px;
                padding-top: 15px;
                .copyright {
                    text-align: right;
                    @include break-at(mobile-lg-max) {
                        text-align: left;
                        margin-top: 20px;
                    }
                }
                .footer-links {
                    background: none;
                    min-height: 60px;
                    padding: 0 15px;
                    a {
                        white-space: nowrap;
                        text-decoration: underline;
                        @include break-at(mobile-lg-max) {
                            display: block;
                            margin-bottom: 20px;
                        }
                    }
                }
            }
        }
    }
    /* Footer - End */
}
