{% load i18n %}
<div class="accessibility-statement">
    <h2 class="">Accessibility statement - Plugin</h2>
    <p>
        <strong>[THIS CONTENT IS NOT AN ACCESSIBILITY STATEMENT]</strong>
    </p>
    <p>
        You can use this plugin to present an accessibility statement if you are required to in your region.
    </p>

    <p>
        Use the Django admin manager to control who can view this plugin. Ensure that users in the Guest group have read access to this plugin to make it visible to people not login in.
    </p>
</div>