$breakpoints: (
    mobile-xsmall-max: (max-width: 374px),
    mobile-small-max: (max-width: 375px),
    mobile-mid-max: (max-width: 470px),
    mobile-lg-max: (max-width: 767px),
    mobile-max: (max-width: 768px),
    tablet-max: (max-width: 999px),
    small-desktop-max: (max-width: 1000px),
    medium-desktop-max: (max-width: 1024px),
    medium-desktop-min: (min-width: 1025px),
    wide-max: (max-width: 1439px),
);